# Various test examples

http://progenetix.org/beacon/variants/?referenceName=NC_000017.11&start=7577120&referenceBases=G&alternateBases=A&debug=1

https://progenetix.org/beacon/g_variants/?filters=NCIT:C7712&output=pgxseg&debug=1

https://progenetix.org/beacon/callsets/?referenceName=17&variantType=DEL&start=5000000&start=7676592&end=7669607&end=10000000&filters=cellosaurus&output=pgxmatrix&debug=1

https://progenetix.org/beacon/callsets?referenceName=17&variantType=DEL&start=5000000&start=7676592&end=7669607&end=10000000&filters=cellosaurus&output=pgxmatrix&debug=1


http://progenetix.org/beacon/biosamples?filters=NCIT:C3697&output=table&debug=1

http://progenetix.org/beacon/biosamples?referenceName=9&start=10000000,12000000&end=12500000,15000000&variantType=DEL&filters=pgx:icdom-81703&debug=1

http://progenetix.org/beacon/biosamples/onekgbs-HG00142/g_variants

http://progenetix.org/beacon/biosamples/pgxbs-kftvhyvb/phenopackets

http://progenetix.org/beacon/biosamples/pgxbs-kftvkafc/?datasetIds=progenetix&output=samplesplot&plot_chros=3,5,6,14&debug=

